@@ -25,13 +25,9 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-
-#include <gdk-pixbuf/gdk-pixbuf.h>
-
 #include <gio/gio.h>
 #include <glib/gstdio.h>
-
-#include <tumbler/tumbler.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <desktop-thumbnailer/desktop-thumbnailer.h>
 
@@ -55,11 +51,6 @@ static void desktop_thumbnailer_finalize(GObject *object);
 
 
 
-struct _DesktopThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _DesktopThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -291,7 +282,7 @@ desktop_thumbnailer_load_thumbnail (DesktopThumbnailer *thumbnailer,
 
       g_object_get (G_OBJECT (thumbnailer), "exec", &exec, NULL);
       res = desktop_thumbnailer_exec_parse (exec,
-                                            path != NULL ? path : "",
+                                            path,
                                             uri,
                                             size,
                                             tmpfilepath,
@@ -363,7 +354,7 @@ desktop_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   GError                     *error  =  NULL;
   GdkPixbuf                  *pixbuf =  NULL;
 
-  g_return_if_fail (IS_DESKTOP_THUMBNAILER (thumbnailer));
+  g_return_if_fail (DESKTOP_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
   g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
 
@@ -407,13 +398,13 @@ desktop_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (error != NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
-      g_signal_emit_by_name (thumbnailer, "ready", info);
+      g_signal_emit_by_name (thumbnailer, "ready", uri);
     }
 
   g_object_unref (thumbnail);
