@@ -26,13 +26,9 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <libffmpegthumbnailer/videothumbnailerc.h>
-
-#include <tumbler/tumbler.h>
-
 #include <ffmpeg-thumbnailer/ffmpeg-thumbnailer.h>
 
 
@@ -49,11 +45,6 @@ static void ffmpeg_thumbnailer_create   (TumblerAbstractThumbnailer *thumbnailer
 
 
 
-struct _FfmpegThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _FfmpegThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -145,7 +136,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   const gchar            *uri;
   gint                    res;
 
-  g_return_if_fail (IS_FFMPEG_THUMBNAILER (thumbnailer));
+  g_return_if_fail (FFMPEG_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
   g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
 
@@ -160,7 +151,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (tumbler_util_guess_is_sparse (info))
   {
     g_debug ("Video file '%s' is probably sparse, skipping", uri);
-    g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
+    g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
                            TUMBLER_ERROR_NO_CONTENT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
     return;
@@ -189,7 +180,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (path == NULL)
     {
       /* there was an error, emit error signal */
-      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
@@ -205,7 +196,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (res != 0)
     {
       /* there was an error, emit error signal */
-      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
@@ -222,7 +213,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (v_stream == NULL)
     {
       /* there was an error, emit error signal */
-      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
@@ -239,7 +230,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (v_pixbuf == NULL)
     {
       /* emit an error signal */
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -272,14 +263,14 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (error != NULL)
     {
       /* emit an error signal */
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
       /* otherwise, the thumbnail is now ready */
-      g_signal_emit_by_name (thumbnailer, "ready", info);
+      g_signal_emit_by_name (thumbnailer, "ready", uri);
     }
 
   /* clean up */
