@@ -29,11 +29,8 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <tumbler/tumbler.h>
-
 #include <font-thumbnailer/font-thumbnailer.h>
 
 
@@ -45,11 +42,6 @@ static void font_thumbnailer_create   (TumblerAbstractThumbnailer *thumbnailer,
 
 
 
-struct _FontThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _FontThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -412,7 +404,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   gsize                   length;
   gint                    n;
 
-  g_return_if_fail (IS_FONT_THUMBNAILER (thumbnailer));
+  g_return_if_fail (FONT_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
   g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
 
@@ -429,7 +421,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* there was an error in the freetype initialization, abort */
       error_msg = g_strdup_printf (_("Could not initialize freetype: %s"),
                                    ft_strerror (font_thumbnailer->library_error));
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              TUMBLER_ERROR, TUMBLER_ERROR_UNSUPPORTED, error_msg);
       g_free (error_msg);
       return;
@@ -442,7 +434,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* there was an error, emit error signal */
       error_msg = g_strdup_printf (_("Could not load file contents: %s"), 
                                    error->message);
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error_msg);
       g_free (error_msg);
 
@@ -462,7 +454,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* the font file could not be loaded, emit an error signal */
       error_msg = g_strdup_printf (_("Could not open font file: %s"),
                                    ft_strerror (ft_error));
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT, error_msg);
       g_free (error_msg);
 
@@ -487,7 +479,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
               /* emit an error signal */
               error_msg = g_strdup_printf (_("Could not set the character map: %s"),
                                            ft_strerror (ft_error));
-              g_signal_emit_by_name (thumbnailer, "error", info,
+              g_signal_emit_by_name (thumbnailer, "error", uri,
                                      TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT, error_msg);
               g_free (error_msg);
 
@@ -515,7 +507,7 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* emit an error signal */
       error_msg = g_strdup_printf (_("Could not render glyphs: %s"),
                                    ft_strerror (ft_error));
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              TUMBLER_ERROR, TUMBLER_ERROR_INVALID_FORMAT, error_msg);
       g_free (error_msg);
 
@@ -547,14 +539,14 @@ font_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (error != NULL)
     {
       /* emit an error signal */
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
       /* otherwise, the thumbnail is now ready */
-      g_signal_emit_by_name (thumbnailer, "ready", info);
+      g_signal_emit_by_name (thumbnailer, "ready", uri);
     }
 
   /* clean up */
