@@ -31,7 +31,6 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <tumbler/tumbler.h>
 
 #include <gst/gst.h>
 #include <gst/tag/tag.h>
@@ -53,11 +52,6 @@ static void gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
 
 
-struct _GstThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _GstThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -549,7 +543,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (tumbler_util_guess_is_sparse (info))
   {
     g_debug ("Video file '%s' is probably sparse, skipping", uri);
-    g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
+    g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
                            TUMBLER_ERROR_NO_CONTENT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
     return;
@@ -562,7 +556,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   g_object_unref (file);
   if (stream == NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -574,7 +568,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   g_object_unref (stream);
   if (size == -1)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -589,7 +583,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   g_free (claimed_type);
   if (uncertain || ! equals)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
       return;
     }
@@ -649,13 +643,13 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
       if (error != NULL)
         {
-          g_signal_emit_by_name (thumbnailer, "error", info,
+          g_signal_emit_by_name (thumbnailer, "error", uri,
                                  error->domain, error->code, error->message);
           g_error_free (error);
         }
       else
         {
-          g_signal_emit_by_name (thumbnailer, "ready", info);
+          g_signal_emit_by_name (thumbnailer, "ready", uri);
         }
     }
   else
@@ -665,7 +659,7 @@ gst_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
         g_set_error (&error, TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT,
                      TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
