@@ -63,11 +63,8 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <tumbler/tumbler.h>
-
 #include <jpeg-thumbnailer/jpeg-thumbnailer.h>
 
 
@@ -81,11 +78,6 @@ static void jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
 
 
-struct _JPEGThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _JPEGThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -794,7 +786,7 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   gint                    width;
   gint                    size;
 
-  g_return_if_fail (IS_JPEG_THUMBNAILER (thumbnailer));
+  g_return_if_fail (JPEG_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
   g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
 
@@ -930,13 +922,13 @@ jpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (error != NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
-      g_signal_emit_by_name (thumbnailer, "ready", info);
+      g_signal_emit_by_name (thumbnailer, "ready", uri);
     }
 
   g_object_unref (flavor);
