@@ -25,11 +25,8 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <tumbler/tumbler.h>
-
 #include <pixbuf-thumbnailer/pixbuf-thumbnailer.h>
 
 
@@ -54,11 +51,6 @@ static void pixbuf_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
 
 
-struct _PixbufThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _PixbufThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -200,7 +192,7 @@ pixbuf_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   GError           *error = NULL;
   GFile            *file;
 
-  g_return_if_fail (IS_PIXBUF_THUMBNAILER (thumbnailer));
+  g_return_if_fail (PIXBUF_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
   g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
 
@@ -218,7 +210,7 @@ pixbuf_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (stream == NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -239,7 +231,7 @@ pixbuf_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (pixbuf == NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
       g_object_unref (thumbnail);
@@ -263,13 +255,13 @@ pixbuf_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (error != NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
-      g_signal_emit_by_name (thumbnailer, "ready", info);
+      g_signal_emit_by_name (thumbnailer, "ready", uri);
     }
 
   g_object_unref (pixbuf);
