@@ -25,13 +25,10 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <poppler.h>
 
-#include <tumbler/tumbler.h>
-
 #include <poppler-thumbnailer/poppler-thumbnailer.h>
 
 
@@ -42,11 +39,6 @@ static void poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
 
 
-struct _PopplerThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _PopplerThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -236,7 +228,7 @@ poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   gsize                   length;
   gint                    width, height;
 
-  g_return_if_fail (IS_POPPLER_THUMBNAILER (thumbnailer));
+  g_return_if_fail (POPPLER_IS_THUMBNAILER (thumbnailer));
   g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable));
   g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
 
@@ -259,7 +251,7 @@ poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
       /* try to load the file contents using GIO */
       if (!g_file_load_contents (file, cancellable, &contents, &length, NULL, &error))
         {
-          g_signal_emit_by_name (thumbnailer, "error", info,
+          g_signal_emit_by_name (thumbnailer, "error", uri,
                                  error->domain, error->code, error->message);
           g_error_free (error);
           g_object_unref (file);
@@ -282,7 +274,7 @@ poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   /* emit an error if both ways to load the document failed */
   if (document == NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
       poppler_thumbnailer_free (contents);
@@ -292,7 +284,7 @@ poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   /* check if the document has content (= at least one page) */
   if (poppler_document_get_n_pages (document) <= 0)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT,
                              _("The document is empty"));
       g_object_unref (document);
@@ -305,7 +297,7 @@ poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (page == NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              TUMBLER_ERROR, TUMBLER_ERROR_NO_CONTENT,
                              _("First page of the document could not be read"));
       g_object_unref (document);
@@ -357,13 +349,13 @@ poppler_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
 
   if (error != NULL)
     {
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
-      g_signal_emit_by_name (thumbnailer, "ready", info);
+      g_signal_emit_by_name (thumbnailer, "ready", uri);
     }
 
 
