@@ -23,22 +23,12 @@
 
 #include <glib-object.h>
 
-#include <tumbler/tumbler.h>
-
 G_BEGIN_DECLS;
 
-#define XDG_CACHE_TYPE_THUMBNAIL            (xdg_cache_thumbnail_get_type ())
-#define XDG_CACHE_THUMBNAIL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), XDG_CACHE_TYPE_THUMBNAIL, XDGCacheThumbnail))
-#define XDG_CACHE_THUMBNAIL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), XDG_CACHE_TYPE_THUMBNAIL, XDGCacheThumbnailClass))
-#define XDG_CACHE_IS_THUMBNAIL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XDG_CACHE_TYPE_THUMBNAIL))
-#define XDG_CACHE_IS_THUMBNAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XDG_CACHE_TYPE_THUMBNAIL)
-#define XDG_CACHE_THUMBNAIL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), XDG_CACHE_TYPE_THUMBNAIL, XDGCacheThumbnailClass))
+#define XDG_CACHE_TYPE_THUMBNAIL (xdg_cache_thumbnail_get_type ())
+G_DECLARE_FINAL_TYPE (XDGCacheThumbnail, xdg_cache_thumbnail, XDG_CACHE, THUMBNAIL, GObject)
 
-typedef struct _XDGCacheThumbnailClass XDGCacheThumbnailClass;
-typedef struct _XDGCacheThumbnail      XDGCacheThumbnail;
-
-GType xdg_cache_thumbnail_get_type (void) G_GNUC_CONST;
-void  xdg_cache_thumbnail_register (TumblerCachePlugin *plugin);
+void xdg_cache_thumbnail_register (TumblerCachePlugin *plugin);
 
 G_END_DECLS;
 
