@@ -18,7 +18,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#if !defined (TUMBLER_INSIDE_TUMBLER_H) && !defined (TUMBLER_COMPILATION)
+#if !defined (_TUMBLER_INSIDE_TUMBLER_H) && !defined (TUMBLER_COMPILATION)
 #error "Only <tumbler/tumbler.h> may be included directly. This file might disappear or change contents."
 #endif
 
@@ -30,8 +30,8 @@
 G_BEGIN_DECLS
 
 #define TUMBLER_MAJOR_VERSION 4
-#define TUMBLER_MINOR_VERSION 17
-#define TUMBLER_MICRO_VERSION 2
+#define TUMBLER_MINOR_VERSION 19
+#define TUMBLER_MICRO_VERSION 0
 
 #define TUMBLER_CHECK_VERSION(major,minor,micro) \
   (TUMBLER_MAJOR_VERSION > (major) \
