@@ -28,12 +28,9 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glib-object.h>
 
 #include <tumbler/tumbler.h>
-
 #include <tumblerd/tumbler-lifo-scheduler.h>
-#include <tumblerd/tumbler-scheduler.h>
 #include <tumblerd/tumbler-utils.h>
 
 
@@ -70,22 +67,17 @@ static void tumbler_lifo_scheduler_dequeue_request   (TumblerSchedulerRequest
 static void tumbler_lifo_scheduler_thread            (gpointer                   data,
                                                       gpointer                   user_data);
 static void tumbler_lifo_scheduler_thumbnailer_error (TumblerThumbnailer        *thumbnailer,
-                                                      TumblerFileInfo           *failed_info,
+                                                      const gchar               *failed_uri,
                                                       GQuark                     error_domain,
                                                       gint                       error_code,
                                                       const gchar               *message,
                                                       TumblerSchedulerRequest   *request);
 static void tumbler_lifo_scheduler_thumbnailer_ready (TumblerThumbnailer        *thumbnailer,
-                                                      TumblerFileInfo           *info,
+                                                      const gchar               *uri,
                                                       TumblerSchedulerRequest   *request);
 
 
 
-struct _TumblerLifoSchedulerClass
-{
-  GObjectClass __parent__;
-};
-
 struct _TumblerLifoScheduler
 {
   GObject __parent__;
@@ -493,11 +485,16 @@ tumbler_lifo_scheduler_thread (gpointer data,
           g_signal_connect (lq->data, "ready",
                             G_CALLBACK (tumbler_lifo_scheduler_thumbnailer_ready), request);
 
+          /* cancel lower priority thumbnailers for this uri on ready signal */
+          g_signal_connect_swapped (lq->data, "ready", G_CALLBACK (g_cancellable_cancel),
+                                    request->cancellables[n]);
+
           /* tell the thumbnailer to generate the thumbnail */
           tumbler_thumbnailer_create (lq->data, request->cancellables[n], request->infos[n]);
 
           /* disconnect from all signals when we're finished */
           g_signal_handlers_disconnect_by_data (lq->data, request);
+          g_signal_handlers_disconnect_by_data (lq->data, request->cancellables[n]);
         }
     }
 
@@ -516,55 +513,41 @@ tumbler_lifo_scheduler_thread (gpointer data,
 
 static void
 tumbler_lifo_scheduler_thumbnailer_error (TumblerThumbnailer      *thumbnailer,
-                                          TumblerFileInfo         *failed_info,
+                                          const gchar             *failed_uri,
                                           GQuark                   error_domain,
                                           gint                     error_code,
                                           const gchar             *message,
                                           TumblerSchedulerRequest *request)
 {
+  const gchar *failed_uris[] = { failed_uri, NULL };
+
   g_return_if_fail (TUMBLER_IS_THUMBNAILER (thumbnailer));
-  g_return_if_fail (TUMBLER_IS_FILE_INFO (failed_info));
+  g_return_if_fail (failed_uri != NULL);
   g_return_if_fail (request != NULL);
   g_return_if_fail (TUMBLER_IS_LIFO_SCHEDULER (request->scheduler));
 
   /* forward the error signal */
-  for (guint n = 0; n < request->length; n++)
-    {
-      if (request->infos[n] == failed_info)
-        {
-          const gchar *failed_uris[] = { tumbler_file_info_get_uri (failed_info), NULL };
-          g_signal_emit_by_name (request->scheduler, "error", request->handle, failed_uris,
-                                 error_domain, error_code, message, request->origin);
-          break;
-        }
-    }
+  g_signal_emit_by_name (request->scheduler, "error", request->handle, failed_uris, 
+                         error_domain, error_code, message, request->origin);
 }
 
 
 
 static void
 tumbler_lifo_scheduler_thumbnailer_ready (TumblerThumbnailer      *thumbnailer,
-                                          TumblerFileInfo         *info,
+                                          const gchar             *uri,
                                           TumblerSchedulerRequest *request)
 {
+  const gchar *uris[] = { uri, NULL };
+
   g_return_if_fail (TUMBLER_IS_THUMBNAILER (thumbnailer));
-  g_return_if_fail (TUMBLER_IS_FILE_INFO (info));
+  g_return_if_fail (uri != NULL);
   g_return_if_fail (request != NULL);
   g_return_if_fail (TUMBLER_IS_LIFO_SCHEDULER (request->scheduler));
 
   /* forward the ready signal */
-  for (guint n = 0; n < request->length; n++)
-    {
-      if (request->infos[n] == info)
-        {
-          const gchar *uris[] = { tumbler_file_info_get_uri (info), NULL };
-          g_signal_emit_by_name (request->scheduler, "ready", request->handle, uris, request->origin);
-
-          /* cancel lower priority thumbnailers for this uri */
-          g_cancellable_cancel (request->cancellables[n]);
-          break;
-        }
-    }
+  g_signal_emit_by_name (request->scheduler, "ready", request->handle, uris, 
+                         request->origin);
 }
 
 
