@@ -34,10 +34,8 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-
 #include <gio/gio.h>
 
-#include <tumblerd/tumbler-component.h>
 #include <tumblerd/tumbler-manager.h>
 #include <tumblerd/tumbler-manager-gdbus.h>
 #include <tumblerd/tumbler-specialized-thumbnailer.h>
@@ -98,11 +96,6 @@ static void             dump_thumbnailers                 (TumblerManager   *man
 
 
 
-struct _TumblerManagerClass
-{
-  TumblerComponentClass __parent__;
-};
-
 struct _TumblerManager
 {
   TumblerComponent __parent__;
