@@ -35,8 +35,6 @@
 #include <syscall.h> 
 #endif
 
-#include <tumbler/tumbler.h>
-
 #include <tumblerd/tumbler-scheduler.h>
 
 
@@ -340,7 +338,7 @@ tumbler_scheduler_thread_use_lower_priority (void)
 
 void
 tumbler_scheduler_thumberr_debuglog (TumblerThumbnailer      *thumbnailer,
-                                     TumblerFileInfo         *failed_info,
+                                     const gchar             *failed_uri,
                                      GQuark                   error_domain,
                                      gint                     error_code,
                                      const gchar             *message,
@@ -349,7 +347,7 @@ tumbler_scheduler_thumberr_debuglog (TumblerThumbnailer      *thumbnailer,
   gchar *text;
 
   g_return_if_fail (TUMBLER_IS_THUMBNAILER (thumbnailer));
-  g_return_if_fail (TUMBLER_IS_FILE_INFO (failed_info));
+  g_return_if_fail (failed_uri != NULL);
   g_return_if_fail (request != NULL);
   g_return_if_fail (TUMBLER_IS_SCHEDULER (request->scheduler));
 
@@ -365,15 +363,7 @@ tumbler_scheduler_thumberr_debuglog (TumblerThumbnailer      *thumbnailer,
                               g_quark_to_string (error_domain), error_code, message);
     }
 
-  for (guint n = 0; n < request->length; n++)
-    {
-      if (request->infos[n] == failed_info)
-        {
-          g_debug ("Failed attempt for job %d, URI '%s': Code %d, message: %s",
-                   request->handle, tumbler_file_info_get_uri (failed_info), error_code, text);
-          break;
-        }
-    }
-
+  g_debug ("Failed attempt for job %d, URI '%s': Code %d, message: %s",
+           request->handle, failed_uri, error_code, text);
   g_free (text);
 }
