@@ -27,7 +27,6 @@
 #include <glib/gprintf.h>
 #include <glib-object.h>
 
-#include <tumbler/tumbler.h>
 #include <tumbler/tumbler-marshal.h>
 
 #include <tumblerd/tumbler-specialized-thumbnailer.h>
@@ -73,11 +72,6 @@ static void tumbler_specialized_thumbnailer_proxy_name_owner_changed (GDBusProxy
                                                                       TumblerSpecializedThumbnailer *thumbnailer);
 
 
-struct _TumblerSpecializedThumbnailerClass
-{
-  TumblerAbstractThumbnailerClass __parent__;
-};
-
 struct _TumblerSpecializedThumbnailer
 {
   TumblerAbstractThumbnailer __parent__;
@@ -97,7 +91,8 @@ struct _SpecializedInfo
   TumblerThumbnailer *thumbnailer;
   GCond               condition;
   TUMBLER_MUTEX       (mutex);
-  TumblerFileInfo    *info;
+  const gchar        *uri;
+  const gchar        *mime_type;
   gboolean            had_callback;
   guint32             handle;
 };
@@ -346,7 +341,7 @@ thumbnailer_proxy_g_signal_cb (GDBusProxy *proxy,
           g_variant_get (parameters, "(u&s)", &handle, &uri);
           if (info->handle == handle) 
             {
-               g_signal_emit_by_name (info->thumbnailer, "ready", info->info);
+               g_signal_emit_by_name (info->thumbnailer, "ready", uri);
             }
         }
     }
@@ -360,7 +355,7 @@ thumbnailer_proxy_g_signal_cb (GDBusProxy *proxy,
           g_variant_get (parameters, "(u&si&s)", &handle, &uri, &error_code, &error_msg);
           if (info->handle == handle) 
             {
-              g_signal_emit_by_name (info->thumbnailer, "error", info->info,
+              g_signal_emit_by_name (info->thumbnailer, "error", uri,
                                      TUMBLER_ERROR, error_code, error_msg);
             }
         }
@@ -398,7 +393,8 @@ tumbler_specialized_thumbnailer_create (TumblerThumbnailer *thumbnailer,
   g_cond_init (&sinfo.condition);
   sinfo.had_callback = FALSE;
   tumbler_mutex_create (sinfo.mutex);
-  sinfo.info = info;
+  sinfo.uri = uri;
+  sinfo.mime_type = tumbler_file_info_get_mime_type (info);
   sinfo.thumbnailer = thumbnailer;
 
   handler_id = g_signal_connect (s->proxy, "g-signal", 
@@ -408,7 +404,7 @@ tumbler_specialized_thumbnailer_create (TumblerThumbnailer *thumbnailer,
                                    "Queue", 
                                    g_variant_new("(sssb)",
                                                  uri,
-                                                 tumbler_file_info_get_mime_type (info),
+                                                 sinfo.mime_type,
                                                  flavor_name,
                                                  /* TODO: Get this bool from scheduler type */
                                                  FALSE),
@@ -435,7 +431,7 @@ tumbler_specialized_thumbnailer_create (TumblerThumbnailer *thumbnailer,
           if (!g_cond_wait_until (&sinfo.condition, &sinfo.mutex, end_time))
             {
               message = g_strdup (_("Failed to call the specialized thumbnailer: timeout"));
-              g_signal_emit_by_name (thumbnailer, "error", info,
+              g_signal_emit_by_name (thumbnailer, "error", uri,
                                      TUMBLER_ERROR, TUMBLER_ERROR_CONNECTION_ERROR, message);
               g_free (message);
             }
@@ -446,7 +442,7 @@ tumbler_specialized_thumbnailer_create (TumblerThumbnailer *thumbnailer,
     {
       message = g_strdup_printf (_("Failed to call the specialized thumbnailer: %s"),
                                  error->message);
-      g_signal_emit_by_name (thumbnailer, "error", info,
+      g_signal_emit_by_name (thumbnailer, "error", uri,
                              TUMBLER_ERROR, TUMBLER_ERROR_CONNECTION_ERROR, message);
       g_free (message);
       g_clear_error (&error);
